# This specfile is licensed under:
# SPDX-License-Identifier: MIT
# SPDX-FileCopyrightText: Fedora Project Authors
# SPDX-FileCopyrightText: 2022 Maxwell G <gotmax@e.email>
# See %%{name}.spec.license for the full license text.

%bcond_without tests

Name:           yt-dlp
Version:        2025.05.22
Release:        %mkrel 1
Summary:        A command-line program to download videos from online video platforms
Group:          Video/Players

License:        Unlicense
URL:            https://github.com/yt-dlp/yt-dlp
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz
# License of the specfile
Source1:        yt-dlp.license
# (tv) ship prebuild man pages as we don't have pandoc:
Source10:       yt-dlp.1

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3dist(brotli)
BuildRequires:  python3dist(certifi)
BuildRequires:  python3dist(mutagen)
BuildRequires:  python3dist(pycryptodomex)
BuildRequires:  python3dist(requests)
BuildRequires:  python3dist(secretstorage)
BuildRequires:  python3dist(setuptools) >= 40.8
BuildRequires:  python3dist(urllib3) >= 1.26.17
BuildRequires:  python3dist(websockets)
BuildRequires:  python3dist(wheel)

%if %{with tests}
# Needed for %%check
BuildRequires:  python3dist(pytest)
%endif

# Needed for docs
#BuildRequires:  pandoc
BuildRequires:  make

Recommends:     ffmpeg

Suggests:       python3dist(keyring)

%description
yt-dlp is a command-line program to download videos from many different online
video platforms, such as youtube.com. The project is a fork of youtube-dl with
additional features and fixes.

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       %{name} >= %{version}-%{release}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Requires:       %{name} >= %{version}-%{release}
Requires:       zsh
Supplements:    (%{name} and zsh)

%description zsh-completion
Zsh command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Requires:       %{name} >= %{version}-%{release}
Requires:       fish
Supplements:    (%{name} and fish)

%description fish-completion
Fish command line completion support for %{name}.

%prep
%autosetup -p1

find -type f ! -executable -name '*.py' -print -exec sed -i -e '1{\@^#!.*@d}' '{}' +

%generate_buildrequires
%pyproject_buildrequires -r

%build
# Docs and shell completions
#make yt-dlp.1 completion-bash completion-zsh completion-fish
make completion-bash completion-zsh completion-fish

# Docs and shell completions are also included in the wheel.
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files yt_dlp

mkdir -p %{buildroot}%{_mandir}/man1
install -m644 %{SOURCE10} %{buildroot}%{_mandir}/man1/

%check
%if %{with tests}
# See https://github.com/yt-dlp/yt-dlp/blob/master/devscripts/run_tests.sh
%pytest -k "not download"
%endif

%files -f %{pyproject_files}
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%doc README.md
%license LICENSE

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files zsh-completion
%{_datadir}/zsh/site-functions/_%{name}

%files fish-completion
%{_datadir}/fish/vendor_completions.d/%{name}.fish


%changelog
* Sat May 24 2025 daviddavid <daviddavid> 2025.05.22-1.mga10
+ Revision: 2186153
- new version: 2025.05.22

* Sat May 03 2025 daviddavid <daviddavid> 2025.04.30-1.mga10
+ Revision: 2180616
- new version: 2025.04.30

* Sat Apr 05 2025 daviddavid <daviddavid> 2025.03.31-1.mga10
+ Revision: 2173544
- new version: 2025.03.31

* Thu Mar 27 2025 daviddavid <daviddavid> 2025.03.26-1.mga10
+ Revision: 2170259
- new version: 2025.03.26

* Tue Mar 25 2025 daviddavid <daviddavid> 2025.03.25-1.mga10
+ Revision: 2169732
- new version: 2025.03.25

* Sat Mar 01 2025 daviddavid <daviddavid> 2025.02.19-2.mga10
+ Revision: 2154444
- rebuild for python 3.13

* Thu Feb 20 2025 daviddavid <daviddavid> 2025.02.19-1.mga10
+ Revision: 2150046
- new version: 2025.02.19

* Thu Jan 30 2025 daviddavid <daviddavid> 2025.01.26-1.mga10
+ Revision: 2143611
- new version: 2025.01.26

* Sun Jan 19 2025 daviddavid <daviddavid> 2025.01.15-1.mga10
+ Revision: 2139848
- new version: 2025.01.15

* Mon Jan 13 2025 daviddavid <daviddavid> 2025.01.12-1.mga10
+ Revision: 2138755
- new version: 2025.01.12

* Fri Jan 03 2025 daviddavid <daviddavid> 2024.12.23-1.mga10
+ Revision: 2135063
- new version: 2024.12.23

* Thu Dec 19 2024 daviddavid <daviddavid> 2024.12.13-1.mga10
+ Revision: 2126151
- new version: 2024.12.13

* Thu Dec 05 2024 daviddavid <daviddavid> 2024.12.03-1.mga10
+ Revision: 2121655
- new version: 2024.12.03

* Fri Nov 22 2024 daviddavid <daviddavid> 2024.11.18-1.mga10
+ Revision: 2118519
- new version: 2024.11.18

* Thu Nov 14 2024 kekepower <kekepower> 2024.11.04-1.mga10
+ Revision: 2115177
- Update to version 2024.11.04

* Wed Oct 23 2024 kekepower <kekepower> 2024.10.22-1.mga10
+ Revision: 2110576
- Update to version 2024.10.22

* Tue Oct 08 2024 kekepower <kekepower> 2024.10.07-1.mga10
+ Revision: 2104165
- Update to version 2024.10.07

* Sat Sep 28 2024 daviddavid <daviddavid> 2024.09.27-1.mga10
+ Revision: 2101693
- new version: 2024.09.27

* Tue Aug 06 2024 kekepower <kekepower> 2024.08.06-1.mga10
+ Revision: 2083806
- Update to version 2024.08.06

* Fri Aug 02 2024 kekepower <kekepower> 2024.08.01-1.mga10
+ Revision: 2083442
- Update to version 2024.08.01

* Thu Jul 25 2024 kekepower <kekepower> 2024.07.25-1.mga10
+ Revision: 2082529
- Update to version 2024.07.25

* Fri Jul 19 2024 kekepower <kekepower> 2024.07.16-1.mga10
+ Revision: 2082073
- Update to version 2024.07.16

* Tue Jul 09 2024 kekepower <kekepower> 2024.07.09-1.mga10
+ Revision: 2080421
- Update to version 2024.07.09

* Mon Jul 08 2024 kekepower <kekepower> 2024.07.07-1.mga10
+ Revision: 2080310
- Update to version 2024.07.07

* Thu Jul 04 2024 daviddavid <daviddavid> 2024.07.02-1.mga10
+ Revision: 2079738
- new version: 2024.07.02

* Tue May 28 2024 daviddavid <daviddavid> 2024.05.27-1.mga10
+ Revision: 2068507
- new version: 2024.05.27

* Wed Apr 10 2024 kekepower <kekepower> 2024.04.09-1.mga10
+ Revision: 2056293
- Update to version 2024.04.09

* Tue Mar 19 2024 kekepower <kekepower> 2024.03.10-1.mga10
+ Revision: 2050723
- Update to version 2024.03.10

* Sun Dec 31 2023 kekepower <kekepower> 2023.12.30-1.mga10
+ Revision: 2024841
- Update to version 2023.12.30

* Mon Dec 18 2023 tv <tv> 2023.11.16-2.mga10
+ Revision: 2018852
- Rebuild for python 3.12

* Thu Nov 16 2023 kekepower <kekepower> 2023.11.16-1.mga10
+ Revision: 2007133
- Update to version 2023.11.16

* Wed Nov 15 2023 kekepower <kekepower> 2023.11.14-1.mga10
+ Revision: 2006836
- Update to version 2023.11.14

* Sat Oct 14 2023 kekepower <kekepower> 2023.10.13-1.mga10
+ Revision: 1996633
- Update to release 2023.10.13

* Mon Oct 09 2023 kekepower <kekepower> 2023.10.07-1.mga10
+ Revision: 1993747
- Update to release 2023.10.07

* Wed Sep 27 2023 papoteur <papoteur> 2023.09.24-2.mga10
+ Revision: 1991363
- rebuild to bump the release, should be over the mga9 one

* Sun Sep 24 2023 kekepower <kekepower> 2023.09.24-1.mga10
+ Revision: 1990339
- Update to version 2023.09.24

* Sat Sep 23 2023 papoteur <papoteur> 2023.07.06-2.mga10
+ Revision: 1989825
- fix for ArteTV

* Thu Aug 31 2023 daviddavid <daviddavid> 2023.07.06-1.mga10
+ Revision: 1982089
- fix release tag

* Thu Aug 31 2023 daviddavid <daviddavid> 2023.07.06-0.1.mga10
+ Revision: 1982084
- new version: 2023.07.06

* Thu Jun 22 2023 kekepower <kekepower> 2023.06.22-1.mga9
+ Revision: 1962797
- Update to version 2023.06.22

* Wed Jun 21 2023 kekepower <kekepower> 2023.06.21-1.mga9
+ Revision: 1962716
- Update to version 2023.06.21

* Fri Feb 17 2023 kekepower <kekepower> 2023.02.17-1.mga9
+ Revision: 1943795
- Update to version 2023.02.17

* Sat Jan 07 2023 kekepower <kekepower> 2023.01.06-1.mga9
+ Revision: 1931039
- Update to version 2023.01.06

* Thu Jan 05 2023 daviddavid <daviddavid> 2023.01.02-1.mga9
+ Revision: 1930466
- new version: 2023.01.02

* Sat Nov 12 2022 kekepower <kekepower> 2022.11.11-1.mga9
+ Revision: 1906371
- Update to version 2022.11.11

* Sat Oct 08 2022 kekepower <kekepower> 2022.10.04-1.mga9
+ Revision: 1895386
- Update to version 2022.10.04

* Tue Sep 13 2022 tv <tv> 2022.09.01-1.mga9
+ Revision: 1887673
- Rename sources so that iurt doesn't pick the wrong file as spec file
- imported package yt-dlp


* Tue Sep 13 2022 Thierry Vignaud <tv@mageia.org> 2022.09.01-1.mga9
- Import from FC

* Fri Sep 02 2022 Maxwell G <gotmax@e.email> - 2022.09.01-1
- Update to 2022.09.01. Fixes rhbz#2123442.

* Fri Aug 19 2022 Maxwell G <gotmax@e.email> - 2022.08.19-1
- Update to 2022.08.19. Fixes rhbz#2118224.

* Tue Aug 09 2022 Maxwell G <gotmax@e.email> - 2022.08.08-1
- Update to 2022.08.08.

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2022.06.29-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jul 04 2022 Maxwell G <gotmax@e.email> - 2022.06.29-2
- Fix shell completions subpackages

* Mon Jul 04 2022 Maxwell G <gotmax@e.email> - 2022.06.29-1
- Update to 2022.06.29. Fixes rhbz#2102238.

* Thu Jun 23 2022 Maxwell G <gotmax@e.email> - 2022.06.22.1-1
- Update to 2022.06.22.1. Fixes rhbz#2100019.

* Fri Jun 17 2022 Maxwell G <gotmax@e.email> - 2022.05.18-3
- Fix gating configuration

* Thu Jun 16 2022 Python Maint <python-maint@redhat.com> - 2022.05.18-2
- Rebuilt for Python 3.11

* Tue May 24 2022 Maxwell G <gotmax@e.email> - 2022.05.18-1
- Update to 2022.05.18. Fixes rhbz#2088564.

* Fri Apr 08 2022 Maxwell G <gotmax@e.email> - 2022.04.08-1
- Update to 2022.04.08. Fixes rhbz#2073359.

* Sat Mar 12 2022 Artem Polishchuk <ego.cordatus@gmail.com> - 2022.03.08.1-2
- build: Make ffmpeg and ffprobe conditional deps for >= f36 only

* Thu Mar 10 2022 Maxwell G <gotmax@e.email> - 2022.03.08.1-1
- Update to 2022.03.08.1. Fixes rhbz#2061973.

* Mon Mar 07 2022 Maxwell G <gotmax@e.email> - 2022.02.04-2
- Add weak dependency on ffmpeg and ffprobe.
- Make shell-completion subpackages optional again.

* Fri Feb 04 2022 Maxwell G <gotmax@e.email> - 2022.2.4-1
- Update to 2022.2.4. Fixes rhbz#2050497.

* Mon Jan 24 2022 Maxwell G <gotmax@e.email> - 2022.01.21-1
- Update to 2022.01.21.

* Sat Jan 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2021.12.27-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Mon Dec 27 2021 Maxwell G <gotmax@e.email> - 2021.12.27-1
- Update to 2021.12.27.

* Sun Dec 26 2021 Maxwell G <gotmax@e.email> - 2021.12.25-1
- Update to 2021.12.25.

* Wed Dec 01 2021 Maxwell G <gotmax@e.email> - 2021.12.01-1
- Update to 2021.12.01.

* Tue Nov 9 2021 Maxwell G <gotmax@e.email> - 2021.11.10.1-1
- Update to 2021.11.10.1.

* Tue Nov 9 2021 Maxwell G <gotmax@e.email> - 2021.10.22-2
- Skip installing unnecessary tox dependencies
- Fix shell-completion subpackages
- Only package README.md; don't generate extra README.txt

* Sat Oct 23 2021 Maxwell G <gotmax@e.email> - 2021.10.22-1
- Update to 2021.10.22

* Sun Oct 10 2021 Maxwell G <gotmax@e.email> - 2021.10.10-1
- Mark LICENSE with %%license instead of %%doc
- Update to 2021.10.10
- Fix non-executable-script rpmlint error
- Use `python3dist(NAME)` for dependencies
- Fix rpm-buildroot-usage rpmlint error

* Sat Oct 9 2021 Maxwell G <gotmax@e.email> - 2021.10.09-1
- Initial package
